==> digikam-3.0.0-beta2.tar.bz2: digikam-3.0.0-beta2/extra/kipi-plugins/htmlexport/kipiplugin_htmlexport.desktop.cmake <==
[Desktop Entry]
Name=HTML Gallery
Name[ast]=Galería HTML
Name[bg]=Галерия в HTML
Name[bs]=HTML Galerija
Name[ca]=Galeria HTML
Name[ca@valencia]=Galeria HTML
Name[cs]=HTML galerie
Name[da]=HTML-galleri
Name[de]=HTML-Galerie
Name[el]=Πινακοθήκη HTML
Name[en_GB]=HTML Gallery
Name[es]=Galería HTML
Name[et]=HTML galerii
Name[eu]=HTML galeria
Name[fi]=HTML-galleria
Name[fr]=Galerie HTML
Name[ga]=Gailearaí HTML
Name[gl]=Galería HTML
Name[he]=גלרית HTML
Name[hne]=एचटीएमएल गैलरी
Name[hu]=HTML galéria
Name[is]=HTML Safn
Name[it]=Galleria HTML
Name[ja]=HTML ギャラリー
Name[km]=វិចិត្រសាល​ HTML
Name[lv]=HTML galerija
Name[nb]=HTML-galleri
Name[nds]=HTML-Sammeln
Name[nl]=HTML-gallerij
Name[pa]=HTML ਗੈਲਰੀ
Name[pl]=Galeria HTML
Name[pt]=Galeria em HTML
Name[pt_BR]=Galeria em HTML
Name[ro]=Galerie HTML
Name[ru]=Галерея в HTML
Name[sk]=HTML galéria
Name[sl]=Galerija HTML
Name[sq]=HTML Gallery
Name[sv]=HTML-galleri
Name[th]=แกลเลอรีภาพแบบ HTML
Name[tr]=HTML Galerisi
Name[uk]=HTML-галерея
Name[x-test]=xxHTML Galleryxx
Name[zh_CN]=HTML 相册
Name[zh_TW]=HTML 藝廊
Comment=A tool to export images collections into a static XHTML page
Comment[ast]=Una ferramienta pa esportar coleiciones d'imáxenes a una páxina web XHTML estática
Comment[bg]=Инструмент за изнасяне на изображения към статична страница в XHTML
Comment[bs]=Alat za izvoz kolekcija slika u statičnu XHTML stranicu
Comment[ca]=Una eina per exportar col·leccions d'imatges a una pàgina XHTML estàtica
Comment[ca@valencia]=Una eina per exportar col·leccions d'imatges a una pàgina XHTML estàtica
Comment[cs]=Nástroj pro export obrázkových kolekcí do statické stránky XHTML
Comment[da]=Et værktøj til at eksportere billedsamlinger til en statisk XHTML-side
Comment[de]=Ein Werkzeug, um Bildersammlungen zu einer statischen XHTML-Seite zu exportieren.
Comment[el]=Εργαλείο για την εξαγωγή συλλογών εικόνων σε μια στατική σελίδα XHTML
Comment[en_GB]=A tool to export images collections into a static XHTML page
Comment[es]=Herramienta para exportar colecciones de imágenes como una página XHTML estática
Comment[et]=Tööriist pildikogude eksportimiseks staatiliste XHTML-lehekülgedena
Comment[eu]=XHTML orrialde estatiko batera irudien bilduma esportatzeko tresna
Comment[fi]=Kuvakokoelman esitys XHTML-muodossa
Comment[fr]=Outil pour l'exportation de collections d'images vers une page XHTML statique
Comment[ga]=Uirlis a easpórtálann íomhánna go leathanach statach XHTML
Comment[gl]=Unha ferramenta para exportar coleccións de imaxes a páxinas XHTML estáticas
Comment[he]=כלי ליצוא אוספי תמונות לדף XHTML סטטי
Comment[hu]=Egy eszköz képgyűjtemények exportálásához statikus XHTML oldalba
Comment[is]=Verkfæri til að vista myndasöfn á statískar HTML-vefsíður
Comment[it]=Uno strumento per esportare raccolte di immagini un una pagina XHTML statica
Comment[ja]=画像コレクションを XHTML ページにエクスポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំការ​ប្រមូល​ផ្ដុំ​រូបភាព​ចេញ​​ទៅ​កាន់​ទំព័រ XHTML ថិតិវន្ត
Comment[lv]=Rīks attēlu kolekcijas eksportēšanai kā statisku XHTML lapu
Comment[nb]=Et verktøy for å eksportere bildesamlinger til en statisk XHTML-side
Comment[nds]=En Warktüüch, mit dat sik Billersammeln na en fast XHTML-Siet exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingsverzamelingen naar een statische XHTML-pagina te exporteren
Comment[pa]=ਚਿੱਤਰ ਭੰਡਾਰ ਨੂੰ ਸਥਿਰ XHTML ਪੇਜ਼ ਵਿੱਚ ਐਕਸਪੋਰਟ ਕਰਨ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do eksportu kolekcji obrazów na statyczną stronę XHTML
Comment[pt]=Uma ferramenta para exportar colectâneas de imagens para uma página XHTML estática
Comment[pt_BR]=Uma ferramenta para exportar coleções de imagens para uma página estática XHTML
Comment[ro]=O unealtă de exportat colecții de imagini într-o pagină XHTML statică
Comment[ru]=Инструмент для экспорта коллекций изображений в статическую страницу XHTML
Comment[sk]=Nástroj na export obrázkov do statickej XHTML stránky
Comment[sl]=Orodje za izvoz zbirk slik v statično stran XHTML
Comment[sq]=Një mjet për të eksportuar koleksionet e imazheve në një faqe statike XHTML
Comment[sv]=Ett verktyg för att exportera bildsamlingar till en statisk XHTML-sida
Comment[th]=เครื่องมือในการส่งออกคลังภาพต่าง ๆ ไว้ในหน้า XHTML แบบตายตัว
Comment[tr]=Resim koleksiyonlarını statik bir XHTML sayfasına aktarmak için bir araç
Comment[uk]=Інструмент для експорту збірок зображень до статичної сторінки XHTML
Comment[x-test]=xxA tool to export images collections into a static XHTML pagexx
Comment[zh_CN]=一个将图像收藏导出为静态 XHTML 页面的工具
Comment[zh_TW]=匯出影像收藏到靜態 XHTML 網頁的工具
Icon=text-html
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_htmlexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Aurelien Gateau, aurelien dot gateau at free dot fr

==> digikam-3.3.0-beta2.tar.bz2: digikam-3.3.0-beta2/extra/kipi-plugins/htmlexport/kipiplugin_htmlexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=HTML Gallery
Name=HTML Gallery
Name[ast]=Galería HTML
Name[bg]=Галерия в HTML
Name[bs]=HTML Galerija
Name[ca]=Galeria HTML
Name[ca@valencia]=Galeria HTML
Name[cs]=HTML galerie
Name[da]=HTML-galleri
Name[de]=HTML-Galerie
Name[el]=Πινακοθήκη HTML
Name[en_GB]=HTML Gallery
Name[es]=Galería HTML
Name[et]=HTML galerii
Name[eu]=HTML galeria
Name[fi]=HTML-galleria
Name[fr]=Galerie HTML
Name[ga]=Gailearaí HTML
Name[gl]=Galería HTML
Name[he]=גלרית HTML
Name[hne]=एचटीएमएल गैलरी
Name[hu]=HTML galéria
Name[is]=HTML Safn
Name[it]=Galleria HTML
Name[ja]=HTML ギャラリー
Name[km]=វិចិត្រសាល​ HTML
Name[lt]=HTML galerija
Name[lv]=HTML galerija
Name[nb]=HTML-galleri
Name[nds]=HTML-Sammeln
Name[nl]=HTML-gallerij
Name[pa]=HTML ਗੈਲਰੀ
Name[pl]=Galeria HTML
Name[pt]=Galeria em HTML
Name[pt_BR]=Galeria em HTML
Name[ro]=Galerie HTML
Name[ru]=Галерея в HTML
Name[sk]=HTML galéria
Name[sl]=Galerija HTML
Name[sq]=HTML Gallery
Name[sv]=HTML-galleri
Name[th]=แกลเลอรีภาพแบบ HTML
Name[tr]=HTML Galerisi
Name[uk]=HTML-галерея
Name[x-test]=xxHTML Galleryxx
Name[zh_CN]=HTML 相册
Name[zh_TW]=HTML 藝廊
Comment=A tool to export images collections into a static XHTML page
Comment[ast]=Una ferramienta pa esportar coleiciones d'imáxenes a una páxina web XHTML estática
Comment[bg]=Инструмент за изнасяне на изображения към статична страница в XHTML
Comment[bs]=Alat za izvoz kolekcija slika u statičnu XHTML stranicu
Comment[ca]=Una eina per exportar col·leccions d'imatges a una pàgina XHTML estàtica
Comment[ca@valencia]=Una eina per exportar col·leccions d'imatges a una pàgina XHTML estàtica
Comment[cs]=Nástroj pro export obrázkových sbírek do statické stránky XHTML
Comment[da]=Et værktøj til at eksportere billedsamlinger til en statisk XHTML-side
Comment[de]=Ein Werkzeug, um Bildersammlungen zu einer statischen XHTML-Seite zu exportieren.
Comment[el]=Εργαλείο για την εξαγωγή συλλογών εικόνων σε μια στατική σελίδα XHTML
Comment[en_GB]=A tool to export images collections into a static XHTML page
Comment[es]=Herramienta para exportar colecciones de imágenes como una página XHTML estática
Comment[et]=Tööriist pildikogude eksportimiseks staatiliste XHTML-lehekülgedena
Comment[eu]=XHTML orrialde estatiko batera irudien bilduma esportatzeko tresna
Comment[fi]=Kuvakokoelman esitys XHTML-muodossa
Comment[fr]=Outil pour l'exportation de collections d'images vers une page XHTML statique
Comment[ga]=Uirlis a easpórtálann íomhánna go leathanach statach XHTML
Comment[gl]=Unha ferramenta para exportar coleccións de imaxes a páxinas XHTML estáticas
Comment[he]=כלי ליצוא אוספי תמונות לדף XHTML סטטי
Comment[hu]=Egy eszköz képgyűjtemények exportálásához statikus XHTML oldalba
Comment[is]=Verkfæri til að vista myndasöfn á statískar HTML-vefsíður
Comment[it]=Uno strumento per esportare raccolte di immagini un una pagina XHTML statica
Comment[ja]=画像コレクションを XHTML ページにエクスポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំការ​ប្រមូល​ផ្ដុំ​រូបភាព​ចេញ​​ទៅ​កាន់​ទំព័រ XHTML ថិតិវន្ត
Comment[lv]=Rīks attēlu kolekcijas eksportēšanai kā statisku XHTML lapu
Comment[nb]=Et verktøy for å eksportere bildesamlinger til en statisk XHTML-side
Comment[nds]=En Warktüüch, mit dat sik Billersammeln na en fast XHTML-Siet exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingsverzamelingen naar een statische XHTML-pagina te exporteren
Comment[pa]=ਚਿੱਤਰ ਭੰਡਾਰ ਨੂੰ ਸਥਿਰ XHTML ਪੇਜ਼ ਵਿੱਚ ਐਕਸਪੋਰਟ ਕਰਨ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do eksportu kolekcji obrazów na statyczną stronę XHTML
Comment[pt]=Uma ferramenta para exportar colectâneas de imagens para uma página XHTML estática
Comment[pt_BR]=Uma ferramenta para exportar coleções de imagens para uma página estática XHTML
Comment[ro]=O unealtă de exportat colecții de imagini într-o pagină XHTML statică
Comment[ru]=Инструмент для экспорта коллекций изображений в статическую страницу XHTML
Comment[sk]=Nástroj na export obrázkov do statickej XHTML stránky
Comment[sl]=Orodje za izvoz zbirk slik v statično stran XHTML
Comment[sq]=Një mjet për të eksportuar koleksionet e imazheve në një faqe statike XHTML
Comment[sv]=Ett verktyg för att exportera bildsamlingar till en statisk XHTML-sida
Comment[th]=เครื่องมือในการส่งออกคลังภาพต่าง ๆ ไว้ในหน้า XHTML แบบตายตัว
Comment[tr]=Resim koleksiyonlarını statik bir XHTML sayfasına aktarmak için bir araç
Comment[uk]=Інструмент для експорту збірок зображень до статичної сторінки XHTML
Comment[x-test]=xxA tool to export images collections into a static XHTML pagexx
Comment[zh_CN]=一个将图像收藏导出为静态 XHTML 页面的工具
Comment[zh_TW]=匯出影像收藏到靜態 XHTML 網頁的工具
Icon=text-html
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_htmlexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Aurelien Gateau, aurelien dot gateau at free dot fr
